@@ -4,14 +4,6 @@ from .element import Element
 
 
 class ExtractedField(Element):
-    """
-    Fields:
-        confidence: Optional[str]
-        conflicts:  List[Any]
-        prompt:     Optional[Prompt]
-        value:      Union[str, float, List[Any]]
-    """
-
     confidence: typing.Optional[str] = None
     conflicts: typing.List[typing.Any] = []
 
